summaryrefslogtreecommitdiff
path: root/include/ruby/impl/intern/sprintf.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/ruby/impl/intern/sprintf.h')
-rw-r--r--include/ruby/impl/intern/sprintf.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/include/ruby/impl/intern/sprintf.h b/include/ruby/impl/intern/sprintf.h
index 68c3dcedc8..49542f28d8 100644
--- a/include/ruby/impl/intern/sprintf.h
+++ b/include/ruby/impl/intern/sprintf.h
@@ -1,5 +1,5 @@
-#ifndef RUBY3_INTERN_SPRINTF_H /*-*-C++-*-vi:se ft=cpp:*/
-#define RUBY3_INTERN_SPRINTF_H
+#ifndef RBIMPL_INTERN_SPRINTF_H /*-*-C++-*-vi:se ft=cpp:*/
+#define RBIMPL_INTERN_SPRINTF_H
/**
* @file
* @author Ruby developers <ruby-core@ruby-lang.org>
@@ -7,7 +7,7 @@
* Permission is hereby granted, to either redistribute and/or
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
* @warning Symbols prefixed with either `RUBY3` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file
* is also an implementation detail. Do not expect it to persist
@@ -24,20 +24,20 @@
#include "ruby/impl/dllexport.h"
#include "ruby/impl/value.h"
-RUBY3_SYMBOL_EXPORT_BEGIN()
+RBIMPL_SYMBOL_EXPORT_BEGIN()
/* sprintf.c */
VALUE rb_f_sprintf(int, const VALUE*);
-RUBY3_ATTR_FORMAT(RUBY3_PRINTF_FORMAT, 1, 2)
+RBIMPL_ATTR_FORMAT(RBIMPL_PRINTF_FORMAT, 1, 2)
VALUE rb_sprintf(const char*, ...);
VALUE rb_vsprintf(const char*, va_list);
-RUBY3_ATTR_FORMAT(RUBY3_PRINTF_FORMAT, 2, 3)
+RBIMPL_ATTR_FORMAT(RBIMPL_PRINTF_FORMAT, 2, 3)
VALUE rb_str_catf(VALUE, const char*, ...);
VALUE rb_str_vcatf(VALUE, const char*, va_list);
VALUE rb_str_format(int, const VALUE *, VALUE);
-RUBY3_SYMBOL_EXPORT_END()
+RBIMPL_SYMBOL_EXPORT_END()
-#endif /* RUBY3_INTERN_SPRINTF_H */
+#endif /* RBIMPL_INTERN_SPRINTF_H */
@@ -7,7 +7,7 @@
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
- * @warning Symbols prefixed with either `RUBY3` or `ruby3` are
+ * @warning Symbols prefixed with either `RBIMPL` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file